@@ -10,7 +10,7 @@
     :license: BSD, see LICENSE for more details.
 """
 
-__version__ = '0.0.4'
+__version__ = '0.0.5'
 
 #DEBUG = True
 
@@ -20,8 +20,8 @@ DATE_FORMAT = '%a, %d %b %Y %H:%M:%S UTC'
 URL_PREFIX = ''
 API_VERSION = ''
 SERVER_NAME = 'localhost:5000'
-PAGING_LIMIT = 50
-PAGING_DEFAULT = 25
+PAGINATION_LIMIT = 50
+PAGINATION_DEFAULT = 25
 LAST_UPDATED = 'updated'
 DATE_CREATED = 'created'
 ID_FIELD = '_id'
