@@ -10,6 +10,11 @@
 
     :copyright: (c) 2012 by Nicola Iarocci.
     :license: BSD, see LICENSE for more details.
+
+    .. versionchanged:: 0.0.5
+       'AUTH_USERNAME_FIELD' keyword added to support 'user-restricted resource
+       access.
+       'X_DOMAIN' keyword added to support Cross-Origin Resource Sharing CORS
 """
 #DEBUG = True
 
@@ -20,14 +25,19 @@ DATE_FORMAT = '%a, %d %b %Y %H:%M:%S UTC'
 API_VERSION = ''
 URL_PREFIX = ''
 SERVER_NAME = 'localhost:5000'
-PAGING_LIMIT = 50
-PAGING_DEFAULT = 25
 LAST_UPDATED = 'updated'
 DATE_CREATED = 'created'
 ID_FIELD = '_id'
 CACHE_CONTROL = ''
 CACHE_EXPIRES = 0
 ITEM_CACHE_CONTROL = ''
+X_DOMAINS = None                # CORS disabled by default.
+
+FILTERS = True                  # filters enbaled by default.
+SORTING = True                  # sorting enabled by default.
+PAGINATION = True               # pagination enabled by default.
+PAGINATION_LIMIT = 50
+PAGINATION_DEFAULT = 25
 
 RESOURCE_METHODS = ['GET']
 ITEM_METHODS = ['GET']
@@ -39,5 +49,8 @@ ITEM_LOOKUP = True
 ITEM_LOOKUP_FIELD = ID_FIELD
 ITEM_URL = '[a-f0-9]{24}'
 
+AUTH_USERNAME_FIELD = ''        # user-restricted resource access is disabled
+                                # by default.
+
 STATUS_OK = "OK"
 STATUS_ERR = "ERR"
