@@ -18,7 +18,7 @@ from flask import Flask
 from werkzeug.routing import BaseConverter
 from werkzeug.serving import WSGIRequestHandler
 from eve.io.mongo import Mongo, Validator
-from eve.exceptions import ConfigException
+from eve.exceptions import ConfigException, SchemaException
 from eve.endpoints import collections_endpoint, item_endpoint, home_endpoint
 from eve.utils import api_prefix
 
@@ -117,14 +117,14 @@ class Eve(Flask):
         Flask itself is available (besides Eve's proper settings).
         """
 
-        # TODO maybe move these to default_settings.py or package __init__
-        default_module = 'eve.default_settings'
-        envvar = 'EVE_SETTINGS'
-
         # load defaults
-        self.config.from_object(default_module)
+        self.config.from_object('eve.default_settings')
 
         # overwrite the defaults with custom user settings:
+
+        # TODO perhaps we should support non-existing settings file, in order
+        # to allow for envvar_only scenarios. However, we should probably
+        # issue a warning
         if os.path.isabs(self.settings):
             pyfile = self.settings
         else:
@@ -134,6 +134,7 @@ class Eve(Flask):
         self.config.from_pyfile(pyfile)
 
         #overwrite settings with custom environment variable
+        envvar = 'EVE_SETTINGS'
         if os.environ.get(envvar):
             self.config.from_envvar(envvar)
 
@@ -195,7 +196,7 @@ class Eve(Flask):
 
             self.validate_roles('allowed_roles', settings, resource)
             self.validate_roles('allowed_item_roles', settings, resource)
-            self.validate_schema(settings['schema'])
+            self.validate_schema(resource, settings['schema'])
 
     def validate_roles(self, directive, candidate, resource):
         """ Validates that user role directives are syntactically and formally
@@ -230,23 +231,47 @@ class Eve(Flask):
                                   (item, ', '.join(diff),
                                    ', '.join(allowed)))
 
-    def validate_schema(self, schema):
+    def validate_schema(self, resource, schema):
+        """ Validates a resource schema.
+
+        :param resource: resource name.
+        :param schema: schema definition for the resource.
+
+        .. versionchanged:: 0.0.5
+           Validation of the 'data_relation' field rule.
+           Now collecting offending items in a list and inserting results into
+           the exception message.
+        """
         # TODO are there other mandatory settings? Validate them here
-        offender = None
+        offenders = []
         if eve.DATE_CREATED in schema:
-            offender = eve.DATE_CREATED
+            offenders.append(eve.DATE_CREATED)
         if eve.LAST_UPDATED in schema:
-            offender = eve.LAST_UPDATED
+            offenders.append(eve.LAST_UPDATED)
         if eve.ID_FIELD in schema:
-            offender = eve.ID_FIELD
-        if offender:
-            raise ConfigException('"%s" field not allowed in schema (will be '
-                                  'handled automatically).' % offender)
+            offenders.append(eve.ID_FIELD)
+        if offenders:
+            raise SchemaException('field(s) "%s" not allowed in "%s" schema '
+                                  '(they will be handled automatically).'
+                                  % (resource, ', '.join(offenders)))
+
+        for field, ruleset in schema.items():
+            if 'data_relation' in ruleset:
+                if 'collection' not in ruleset['data_relation']:
+                    raise SchemaException("'collection' key is mandatory for "
+                                          "the 'data_relation' rule in "
+                                          "'%s: %s'" % (resource, field))
 
     def set_defaults(self):
         """ When not provided, fills individual resource settings with default
         or global configuration settings.
 
+        .. versionchanged:: 0.0.5
+           'auth_username_field'
+           'filters',
+           'sorting',
+           'pagination'.
+
         .. versionchanged:: 0.0.4
            'defaults',
            'datasource',
@@ -273,19 +298,22 @@ class Eve(Flask):
             settings.setdefault('item_url', self.config['ITEM_URL'])
             settings.setdefault('item_title',
                                 resource.rstrip('s').capitalize())
-            settings.setdefault('item_cache_control',
-                                self.config['ITEM_CACHE_CONTROL'])
             settings.setdefault('item_lookup', self.config['ITEM_LOOKUP'])
             settings.setdefault('public_item_methods',
                                 self.config['PUBLIC_ITEM_METHODS'])
             settings.setdefault('allowed_item_roles',
                                 self.config['ALLOWED_ITEM_ROLES'])
+            settings.setdefault('filters', self.config['FILTERS'])
+            settings.setdefault('sorting', self.config['SORTING'])
+            settings.setdefault('pagination', self.config['PAGINATION'])
             # TODO make sure that this we really need the test below
             if settings['item_lookup']:
                 item_methods = self.config['ITEM_METHODS']
             else:
                 item_methods = eve.ITEM_METHODS
             settings.setdefault('item_methods', item_methods)
+            settings.setdefault('auth_username_field',
+                                self.config['AUTH_USERNAME_FIELD'])
 
             datasource = {}
             settings.setdefault('datasource', datasource)
@@ -294,8 +322,7 @@ class Eve(Flask):
 
             # empty schemas are allowed for read-only access to resources
             schema = settings.setdefault('schema', {})
-
-            # TODO fill schema{} defaults, like field type, etc.
+            self.set_schema_defaults(schema)
 
             # `dates` helper set contains the names of the schema fields
             # defined as `datetime` types. It will come in handy when
@@ -314,10 +341,30 @@ class Eve(Flask):
                 set(field for field, definition in schema.items()
                     if definition.get('default'))
 
+    def set_schema_defaults(self, schema):
+        """ When not provided, fills individual schema settings with default
+        or global configuration settings.
+
+        :param schema: the resoursce schema to be intialized with default
+                       values
+
+        .. versionadded: 0.0.5
+        """
+        # TODO fill schema{} defaults, like field type, etc.
+        for field, ruleset in schema.items():
+            if 'data_relation' in ruleset:
+                ruleset['data_relation'].setdefault('field',
+                                                    self.config['ID_FIELD'])
+
     def _add_url_rules(self):
         """ Builds the API url map. Methods are enabled for each mapped
         endpoint, as configured in the settings.
 
+        .. versionchanged:: 0.0.5
+           Support for Cross-Origin Resource Sharing. 'OPTIONS' method is
+           explicitly routed to standard endpoints to allow for proper CORS
+           processing.
+
         .. versionchanged:: 0.0.4
            config.SOURCES. Maps resources to their datasources.
 
@@ -333,7 +380,8 @@ class Eve(Flask):
                             self.config['API_VERSION'])
 
         # home page (API entry point)
-        self.add_url_rule('%s/' % prefix, 'home', home_endpoint)
+        self.add_url_rule('%s/' % prefix, 'home', view_func=home_endpoint,
+                          methods=['GET', 'OPTIONS'])
 
         for resource, settings in self.config['DOMAIN'].items():
             resources[settings['url']] = resource
@@ -343,7 +391,7 @@ class Eve(Flask):
             # resource endpoint
             url = '%s/<regex("%s"):url>/' % (prefix, settings['url'])
             self.add_url_rule(url, view_func=collections_endpoint,
-                              methods=settings['methods'])
+                              methods=settings['methods'] + ['OPTIONS'])
 
             # item endpoint
             if settings['item_lookup']:
@@ -353,7 +401,8 @@ class Eve(Flask):
                      settings['item_lookup_field'])
 
                 self.add_url_rule(item_url, view_func=item_endpoint,
-                                  methods=settings['item_methods'])
+                                  methods=settings['item_methods']
+                                  + ['OPTIONS'])
                 if 'PATCH' in settings['item_methods']:
                     # support for POST with X-HTTM-Method-Override header
                     # for clients not supporting PATCH. Also see
