@@ -12,7 +12,7 @@
 
 import ast
 import simplejson as json
-from flask import abort
+from flask import abort, request
 from flask.ext.pymongo import PyMongo
 from datetime import datetime
 from bson import ObjectId
@@ -49,12 +49,17 @@ class Mongo(DataLayer):
         :param resource: resource name.
         :param req: a :class:`ParsedRequest`instance.
 
+        .. versionchanged:: 0.0.5
+           handles the case where req.max_results is None because pagination
+           has been disabled.
+
         .. versionchanged:: 0.0.4
            retrieves the target collection via the new config.SOURCES helper.
         """
         args = dict()
 
-        args['limit'] = req.max_results
+        if req.max_results:
+            args['limit'] = req.max_results
 
         if req.page > 1:
             args['skip'] = (req.page - 1) * req.max_results
@@ -115,7 +120,7 @@ class Mongo(DataLayer):
            retrieves the target collection via the new config.SOURCES helper.
         """
         datasource, filter_ = self._datasource_ex(resource)
-        return  self.driver.db[datasource].insert(document)
+        return self.driver.db[datasource].insert(document)
 
     def update(self, resource, id_, updates):
         """Updates a collection document.
@@ -162,6 +167,9 @@ class Mongo(DataLayer):
         """ Returns both db collection and exact query (base filter included)
         to which an API resource refers to
 
+        .. versionchanged:: 0.0.5
+           Support for 'user-restricted resource access'.
+
         .. versionadded:: 0.0.4
         """
 
@@ -171,4 +179,11 @@ class Mongo(DataLayer):
                 query.update(filter_)
             else:
                 query = filter_
+
+        # if 'user-restricted resource access' is enabled and there's an Auth
+        # request active, add the username field to the query
+        username_field = config.DOMAIN[resource].get('auth_username_field')
+        if username_field and request.authorization and query:
+            query.update({username_field: request.authorization.username})
+
         return datasource, query
