@@ -33,6 +33,11 @@ def get(resource):
 
     :param resource: the name of the resource.
 
+    .. versionchanged:: 0.0.5
+       Support for user-restricted access to resources.
+       Support for LAST_UPDATED field missing from documents, because they were
+       created outside the API context.
+
     .. versionchanged:: 0.0.4
        Added the ``requires_auth`` decorator.
 
@@ -44,25 +49,13 @@ def get(resource):
 
     documents = []
     response = {}
-    last_updated = datetime.min
+    last_updated = _epoch()
 
-    req = parse_request()
+    req = parse_request(resource)
     cursor = app.data.find(resource, req)
     for document in cursor:
-        # flask-pymongo returns timezone-aware value, we strip it out
-        # because std lib datetime doesn't provide that, and comparisions
-        # between the two values would fail
-
-        # TODO consider testing if the app.data is of type Mongo before
-        # replacing the tzinfo. On the other hand this could be handy for
-        # other drivers as well (think of it as a safety measure). A
-        # 'pythonic' alternative would be to perform the comparision in a
-        # try..catch statement.. performing the replace in case of an
-        # exception. However that would mean getting the exception at each
-        # execution under standard circumstances (the default driver being
-        # Mongo).
-        document[config.LAST_UPDATED] = \
-            document[config.LAST_UPDATED].replace(tzinfo=None)
+        document[config.LAST_UPDATED] = _last_updated(document)
+        document[config.DATE_CREATED] = _date_created(document)
 
         if document[config.LAST_UPDATED] > last_updated:
             last_updated = document[config.LAST_UPDATED]
@@ -72,6 +65,8 @@ def get(resource):
         document['_links'] = {'self': document_link(resource,
                                                     document[config.ID_FIELD])}
 
+        _strip_username(document, resource)
+
         documents.append(document)
 
     if req.if_modified_since and len(documents) == 0:
@@ -82,7 +77,7 @@ def get(resource):
         last_modified = None
     else:
         status = 200
-        last_modified = last_updated if last_updated > datetime.min else None
+        last_modified = last_updated if last_updated > _epoch() else None
         response['_items'] = documents
         response['_links'] = _pagination_links(resource, req, cursor.count())
 
@@ -97,6 +92,11 @@ def getitem(resource, **lookup):
     :param resource: the name of the resource to which the document belongs.
     :param **lookup: the lookup query.
 
+    .. versionchanged:: 0.0.5
+       Support for user-restricted access to resources.
+       Support for LAST_UPDATED field missing from documents, because they were
+       created outside the API context.
+
     .. versionchanged:: 0.0.4
        Added the ``requires_auth`` decorator.
 
@@ -106,16 +106,17 @@ def getitem(resource, **lookup):
     """
     response = {}
 
-    req = parse_request()
+    req = parse_request(resource)
     document = app.data.find_one(resource, **lookup)
     if document:
         # need to update the document field as well since the etag must
         # be computed on the same document representation that might have
         # been used in the collection 'get' method
-        last_modified = document[config.LAST_UPDATED] = \
-            document[config.LAST_UPDATED].replace(tzinfo=None)
+        last_modified = document[config.LAST_UPDATED] = _last_updated(document)
         etag = document_etag(document)
 
+        _strip_username(document, resource)
+
         if req.if_none_match and etag == req.if_none_match:
             # request etag matches the current server representation of the
             # document, return a 304 Not-Modified.
@@ -138,6 +139,18 @@ def getitem(resource, **lookup):
     abort(404)
 
 
+def _strip_username(document, resource):
+        """If 'user-restricted resource access' is enabled and there's
+        an Auth request active, strim the username out of the document
+
+        .. versionadded:: 0.0.5
+        """
+        username_field = app.config['DOMAIN'][resource]['auth_username_field']
+        if username_field:
+            document.pop(username_field, None)
+        return document
+
+
 def _pagination_links(resource, req, documents_count):
     """Returns the appropriate set of resource links depending on the
     current page and the total number of documents returned by the query.
@@ -146,12 +159,15 @@ def _pagination_links(resource, req, documents_count):
     :param req: and instace of :class:`eve.utils.ParsedRequest`.
     :param document_count: the number of documents returned by the query.
 
+    .. versionchanged:: 0.0.5
+       Support for optional pagination.
+
     .. versionchanged:: 0.0.3
        JSON links
     """
     _links = {'parent': home_link(), 'self': collection_link(resource)}
 
-    if documents_count:
+    if documents_count and config.DOMAIN[resource]['pagination']:
         if req.page * req.max_results < documents_count:
             q = querydef(req.max_results, req.where, req.sort, req.page + 1)
             _links['next'] = {'title': 'next page', 'href': '%s%s' %
@@ -165,8 +181,42 @@ def _pagination_links(resource, req, documents_count):
     return _links
 
 
-def standard_links(resource):
-    """Returns the standard set of resource links that are included in every
-    kind of GET response.
+def _last_updated(document):
+    """Fixes document's LAST_UPDATED field value. Flask-PyMongo returns
+    timezone-aware values while stdlib datetime values are timezone-naive.
+    Comparisions between the two would fail.
+
+    If LAST_UPDATE is missing we assume that it has been created outside of the
+    API context and inject a default value, to allow for proper computing of
+    Last-Modified header tag. By design all documents return a LAST_UPDATED
+    (and we don't want to break existing clients).
+
+    :param document: the document to be processed.
+
+    .. versionadded:: 0.0.5
     """
-    return [home_link(), collection_link(resource)]
+    if config.LAST_UPDATED in document:
+        return document[config.LAST_UPDATED].replace(tzinfo=None)
+    else:
+        return _epoch()
+
+
+def _date_created(document):
+    """If DATE_CREATED is missing we assume that it has been created outside of
+    the API context and inject a default value. By design all documents
+    return a DATE_CREATED (and we dont' want to break existing clients).
+
+    :param document: the document to be processed.
+
+    .. versionadded:: 0.0.5
+    """
+    return document[config.DATE_CREATED] if config.DATE_CREATED in document \
+        else _epoch()
+
+
+def _epoch():
+    """ A datetime.min alternative which won't crash on us.
+
+    .. versionadded:: 0.0.5
+    """
+    return datetime(1970, 1, 1)
