@@ -6,7 +6,7 @@ from eve.flaskapp import RegexConverter
 from eve.flaskapp import Eve
 from eve.io.base import DataLayer
 from eve.tests import TestBase
-from eve.exceptions import ConfigException
+from eve.exceptions import ConfigException, SchemaException
 from eve.io.mongo import Mongo, Validator
 
 
@@ -108,13 +108,23 @@ class TestConfig(TestBase):
 
     def assertUnallowedField(self, field):
         self.domain.clear()
-        self.domain['resource'] = {
-            'schema': {
-                field: {'type': 'datetime'}
-            }
-        }
+        schema = {field: {'type': 'datetime'}}
+        self.domain['resource'] = {'schema': schema}
         self.app.set_defaults()
-        self.assertValidateConfigFailure('automatically')
+        self.assertValidateSchemaFailure('resource', schema, field)
+
+    def test_validate_schema(self):
+        # lack of 'collection' key for 'data_collection' rule
+        schema = self.domain['invoices']['schema']
+        del(schema['person']['data_relation']['collection'])
+        self.assertValidateSchemaFailure('invoices', schema, 'collection')
+
+    def test_set_schema_defaults(self):
+        # default data_relation field value
+        schema = self.domain['invoices']['schema']
+        data_relation = schema['person']['data_relation']
+        self.assertTrue('field' in data_relation)
+        self.assertEqual(data_relation['field'], self.app.config['ID_FIELD'])
 
     def test_set_defaults(self):
         self.domain.clear()
@@ -149,8 +159,12 @@ class TestConfig(TestBase):
                          self.app.config['ITEM_URL'])
         self.assertEqual(settings['item_title'],
                          resource.rstrip('s').capitalize())
-        self.assertEqual(settings['item_cache_control'],
-                         self.app.config['ITEM_CACHE_CONTROL'])
+        self.assertEqual(settings['filters'], self.app.config['FILTERS'])
+        self.assertEqual(settings['sorting'], self.app.config['SORTING'])
+        self.assertEqual(settings['pagination'], self.app.config['PAGINATION'])
+        self.assertEqual(settings['auth_username_field'],
+                         self.app.config['AUTH_USERNAME_FIELD'])
+
         self.assertNotEqual(settings['schema'], None)
         self.assertEqual(type(settings['schema']), dict)
         self.assertEqual(len(settings['schema']), 0)
@@ -188,6 +202,14 @@ class TestConfig(TestBase):
         else:
             self.fail("ConfigException expected but not raised.")
 
+    def assertValidateSchemaFailure(self, resource, schema, expected):
+        try:
+            self.app.validate_schema(resource, schema)
+        except SchemaException, e:
+            self.assertTrue(expected.lower() in str(e).lower())
+        else:
+            self.fail("SchemaException expected but not raised.")
+
     def test_schema_dates(self):
         self.domain.clear()
         self.domain['resource'] = {
