@@ -53,8 +53,8 @@ class ParsedRequest(object):
     page = 1
 
     # `max_result` value of the query string (?max_results). Defaults to
-    # `PAGING_DEFAULT`.
-    max_results = config.PAGING_DEFAULT
+    # `PAGINATION_DEFAULT` unless pagination is disabled.
+    max_results = config.PAGINATION_DEFAULT
 
     # `If-Modified-Since` request header value. Defaults to None.
     if_modified_since = None
@@ -66,14 +66,18 @@ class ParsedRequest(object):
     if_match = None
 
 
-def parse_request(args=None, headers=None):
+def parse_request(resource=None, args=None, headers=None):
     """ Parses a client request, returning instance of :class:`ParsedRequest`
     containing relevant request data.
 
+    :param resource: the resource currently being accessed by the client.
     :param args: request arguments. This is only used by the test suite as we
                  usually process flask request object.
     :param headers: request headers. Only used by the test suite as we usually
                     process flask request object.
+
+    .. versionchanged: 0.0.5
+       Support for optional filters, sorting and pagination.
     """
     if flask.has_request_context():
             args = request.args
@@ -82,27 +86,32 @@ def parse_request(args=None, headers=None):
     r = ParsedRequest()
 
     if args:
-        r.where = args.get('where')
-        r.sort = args.get('sort')
+        if resource is None or config.DOMAIN[resource]['filters']:
+            r.where = args.get('where')
+        if resource is None or config.DOMAIN[resource]['sorting']:
+            r.sort = args.get('sort')
 
-        # TODO should probably return a 400 if 'page' is < 1 or non-numeric
-        if 'page' in args:
-            try:
-                r.page = abs(int(args.get('page'))) or 1
-            except ValueError:
-                pass
+        if resource is None or config.DOMAIN[resource]['pagination']:
+            # TODO should probably return a 400 if 'page' is < 1 or non-numeric
+            if 'page' in args:
+                try:
+                    r.page = abs(int(args.get('page'))) or 1
+                except ValueError:
+                    pass
 
-        # TODO should probably return a 400 if 'max_results' < 1 or
-        # non-numeric
-        if 'max_results' in args:
-            try:
-                r.max_results = int(args.get('max_results'))
-                if r.max_results > config.PAGING_LIMIT:
-                    r.max_results = config.PAGING_LIMIT
-                elif r.max_results <= 0:
-                    r.max_results = config.PAGING_DEFAULT
-            except ValueError:
-                pass
+            # TODO should probably return a 400 if 'max_results' < 1 or
+            # non-numeric
+            if 'max_results' in args:
+                try:
+                    r.max_results = int(args.get('max_results'))
+                    if r.max_results > config.PAGINATION_LIMIT:
+                        r.max_results = config.PAGINATION_LIMIT
+                    elif r.max_results <= 0:
+                        r.max_results = config.PAGINATION_DEFAULT
+                except ValueError:
+                    pass
+        else:
+            r.max_results = None
 
     if headers:
         r.if_modified_since = weak_date(headers.get('If-Modified-Since'))
@@ -214,12 +223,12 @@ def api_prefix(url_prefix=None, api_version=None):
     return prefix + version
 
 
-def querydef(max_results=config.PAGING_DEFAULT, where=None, sort=None,
+def querydef(max_results=config.PAGINATION_DEFAULT, where=None, sort=None,
              page=None):
     """ Returns a valid query string.
 
     :param max_results: `max_result` part of the query string. Defaults to
-                        `PAGING_DEFAULT`
+                        `PAGINATION_DEFAULT`
     :param where: `where` part of the query string. Defaults to None.
     :param sort: `sort` part of the query string. Defaults to None.
     :param page: `page` parte of the query string. Defaults to None.
@@ -228,7 +237,7 @@ def querydef(max_results=config.PAGING_DEFAULT, where=None, sort=None,
     sort_part = '&sort=%s' % sort if sort else ''
     page_part = '&page=%s' % page if page > 1 else ''
     max_results_part = 'max_results=%s' % max_results \
-        if max_results != config.PAGING_DEFAULT else ''
+        if max_results != config.PAGINATION_DEFAULT else ''
 
     return ('?' + ''.join([max_results_part, where_part, sort_part,
                            page_part]).lstrip('&')).rstrip('?')
